/*
 * CustomerServiceMock.java
 */

package com.example.business;
import java.util.Iterator;
import java.util.List;
import java.util.ArrayList;
import com.example.model.CompanyBO;
import com.example.model.CustomerBO;
import com.example.integration.DataAccessException;

/**
 * Mock object for interface CustomerService.
 */
public class CustomerServiceMock implements CustomerService {

    /**
     * Find customers based on the given criteria.
     * @param criteria find criteria.
     * @return the list of CustomerBO objects.
     */
    public List findCustomer(CustomerCriteria criteria) {
        if (criteria.getName() == null) {
            criteria.setName("");
        }
        if (criteria.getCompany() == null) {
            criteria.setCompany("");
        }
        List result = new ArrayList();
        for (Iterator it = list.iterator(); it.hasNext();) {
            CustomerBO cust = (CustomerBO)it.next();
            String full = cust.getName().getLast()
                + cust.getName().getFirst();
            if ((cust.getName().getFirst().indexOf(criteria.getName()) >= 0
                || cust.getName().getLast().indexOf(criteria.getName()) >= 0
                || full.indexOf(criteria.getName()) >= 0)
                && (cust.getCompany().getName()
                    .indexOf(criteria.getCompany()) >= 0)) {
                result.add(cust);
            }
        }
        return result;
    }

    /**
     * Delete customer which has the specified id.
     * 
     * @param id the customer id.
     * @param criteria find criteria.
     * @return the list of CustomerBO objects.
     */
    public List deleteCustomer(int id, CustomerCriteria criteria) {
        for (Iterator it = list.iterator(); it.hasNext();) {
            CustomerBO cust = (CustomerBO)it.next();
            if (cust.getId() == id) {
                it.remove();
                return findCustomer(criteria);
            }
        }
        throw new DataAccessException("No Such Customer found: id=" + id);
    }

    /**
     * the list of dummy data.
     */
    private List list = new ArrayList();
    
    /**
     * Constructor.
     */
    public CustomerServiceMock() {
        CompanyBO comp1 = new CompanyBO(1, "山中ハウス(株)");
        CompanyBO comp2 = new CompanyBO(2, "セイレ化学(株)");
        CompanyBO comp3 = new CompanyBO(3, "(株)エービーシー");
        
        CustomerBO cust1 = new CustomerBO(1, "小田", "拓郎", "oda@yhouse.com",
                                            comp1);
        CustomerBO cust2 = new CustomerBO(2, "奥田", "和正", "okuda@yhouse.com",
                                            comp1);
        CustomerBO cust3 = new CustomerBO(3, "加藤", "民生", "katoh@seire.com",
                                            comp2);
        CustomerBO cust4 = new CustomerBO(4, "鈴木", "和彦", "suzuki@seire.com",
                                            comp2);
        CustomerBO cust5 = new CustomerBO(5, "平井", "雅之", "hirai@seire.com",
                                            comp2);
        CustomerBO cust6 = new CustomerBO(6, "福山", "堅", "fukuyama@abc.com",
                                            comp3);
        CustomerBO cust7 = new CustomerBO(7, "吉田", "雅治", "yoshida@abc.com",
                                            comp3);
        list.add(cust1);
        list.add(cust2);
        list.add(cust3);
        list.add(cust4);
        list.add(cust5);
        list.add(cust6);
        list.add(cust7);
    }
}
