/*
 * CustomerDAOImpl.java
 *
 */

package com.example.integration;

import java.util.List;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import com.example.model.CustomerBO;

/**
 * CustomerDAO implementation.
 */
public class CustomerDAOImpl implements CustomerDAO {
    
    /** Hibernate session factory */
    private SessionFactory sessionFactory;
    
    /**
     * Set Hibernate session.
     *
     * @param sessionFactory Hibernate session factory.
     */
    public void setSessionFactory(SessionFactory sessionFactory) {
        this.sessionFactory = sessionFactory;
    }
    
    /**
     * Finds customers by customer name and company name.
     *
     * @param name customer name.
     * @param company company name.
     * @return the list of CustomerBO.
     */
    public List find(String name, String company) {
        Session session = HibernateUtil.getSession(sessionFactory);
        // パラメータ指定の有無により，検索条件を構築する．
        StringBuffer sql = new StringBuffer();
        if (name != null && !name.equals("")) {
            name = "'%" + name + "%'";
            sql.append(" where (c.name.first like ").append(name);
            sql.append(" or c.name.last like ").append(name);
            sql.append(" or c.name.last || c.name.first like ").append(name)
               .append(")");
        }        
        if (company != null && !company.equals("")) {
            company = "'%" + company + "%'";
            String prep = sql.length() == 0 ? " where" : " and";
            sql.append(prep);
            sql.append(" c.company.name like ").append(company);
        }
        sql.insert(0, "from CustomerBO c join fetch c.company");
        sql.append(" order by c.id asc");
        
        return session.createQuery(sql.toString()).list();

//        Criteria criteria = session.createCriteria(CustomerBO.class)
//        .setFetchMode("company", FetchMode.JOIN);
//        
//        if (name != null && !name.equals("")) {
//            criteria.add(Expression.or(
//                    Expression.ilike("name.first", name, MatchMode.ANYWHERE),
//                    Expression.ilike("name.last", name, MatchMode.ANYWHERE)));
//        }
//        
//        if (company != null && !company.equals("")) {
//            criteria.createAlias("company", "company")
//            .add(Expression.ilike("company.name", company,
//                    MatchMode.ANYWHERE));
//        }
//        
//        criteria.addOrder(Order.asc("id"));
//        return criteria.list();
    }
    
    /**
     * Delete customer which has the specified id.
     *
     * @param id customer id.
     */
    public void delete(int id) {
        Session session = HibernateUtil.getSession(this.sessionFactory);
        CustomerBO customer = (CustomerBO)
            session.get(CustomerBO.class, new Integer(id));
        session.delete(customer);

//        session.createQuery("delete CustomerBO where id = :id")
//            .setInteger("id", id)
//            .executeUpdate();
    }
    
}
