/*
 * HibernateUtil.java
 *
 */

package com.example.integration;

import java.util.logging.Logger;
import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;
import org.hibernate.Session;
import org.hibernate.SessionFactory;

/**
 * Hibernate Utility.
 */
public class HibernateUtil {
    
    /** Logger */
    private static Logger log = Logger.getLogger(
            com.example.integration.HibernateUtil.class.getName());
    
    /**
     * Session object cache in ThreadLocal.
     */
    static ThreadLocal holder = new ThreadLocal() {
        protected synchronized Object initialValue() {
            return new HashMap();
        }
    };
    
    /**
     * Create Session object from SessionFactory.
     * @param factory Hibernate SessionFactory
     * @return Hibernate Session
     */
    public static Session getSession(SessionFactory factory) {
        Map sessionMap = (Map)holder.get();
        Session session = (Session)sessionMap.get(factory);
        if (session == null) {
            log.fine("Obtaining new Session.");
            session = factory.openSession();
            sessionMap.put(factory, session);
        }
        
        if (!session.isConnected()) {
            log.fine("Reconnectiog the Session.");
            session.reconnect();
        }
        return session;
    }
    
    /**
     * Close all session objects in the current thread.
     */
    public static void closeAllSessions() {
        log.fine("Closing and trashing all Sessions in this thread.");
        Map sessionMap = (Map)holder.get();
        for (Iterator it = sessionMap.values().iterator();
        it.hasNext();) {
            Session session = (Session)it.next();
            if (session != null && session.isOpen()) {
                session.close();
            }
        }
        sessionMap.clear();
    }
}