/*
 * ContextUtil.java
 */

package com.example.util;

import java.security.Principal;
import javax.ejb.EJBContext;
import javax.faces.context.FacesContext;

/**
 * Context utility class.
 */
public class ContextUtil {
    
    /** Current EJB context. */
    private static ThreadLocal currentEJBContext = new ThreadLocal();
    
    /**
     * Sets current EJB context.
     * @param context EJBContext
     */
    public static void setEJBContext(EJBContext context) {
        currentEJBContext.set(context);
    }
    
    /**
     * Gets current EJB context.
     * @return EJBContext
     */
    public static EJBContext getEJBContext() {
        return (EJBContext)currentEJBContext.get();
    }

    /**
     * Test if the caller has a given security role.
     * @param role the name of security role.
     * @return true if the caller has the specified role.
     */
    public static boolean isUserInRole(String role) {
        EJBContext ctx = getEJBContext();
        if (ctx != null) {
            // サービスオブジェクトはEJBコンテナで動いている
            return ctx.isCallerInRole(role);
        }
        else {
            // サービスオブジェクトはWebコンテナで動いている
            return FacesContext.getCurrentInstance()
                .getExternalContext().isUserInRole(role);
        }
    }
    
    /**
     * Return the current authenticated user principal.
     * @return Princiapl object.
     */
    public static Principal getUserPrincipal() {
        EJBContext ctx = getEJBContext();
        if (ctx != null) {
            // サービスオブジェクトはEJBコンテナで動いている
            return ctx.getCallerPrincipal();
        }
        else {
            // サービスオブジェクトはWebコンテナで動いている
            return FacesContext.getCurrentInstance()
                .getExternalContext().getUserPrincipal();
        }
    }
}
